==> ocaml_3.04.orig.tar.gz: ocaml-3.04/otherlibs/labltk/browser/viewer.mli <==
(*************************************************************************)
(*                                                                       *)
(*                Objective Caml LablTk library                          *)
(*                                                                       *)
(*            Jacques Garrigue, Kyoto University RIMS                    *)
(*                                                                       *)
(*   Copyright 1999 Institut National de Recherche en Informatique et    *)
(*   en Automatique and Kyoto University.  All rights reserved.          *)
(*   This file is distributed under the terms of the GNU Library         *)
(*   General Public License, with the special exception on linking       *)
(*   described in file ../../../LICENSE.                                 *)
(*                                                                       *)
(*************************************************************************)

(* $Id: viewer.mli,v 1.6 2001/12/07 13:40:03 xleroy Exp $ *)

(* Module viewer *)
open Widget

val search_symbol : unit -> unit
        (* search a symbol in all modules in the path *)

val f : ?dir:string -> ?on:toplevel widget -> unit -> unit
        (* open then module viewer *)
val st_viewer : ?dir:string -> ?on:toplevel widget -> unit -> unit
        (* one-box viewer *)

val view_defined : Longident.t -> env:Env.t -> unit
        (* displays a signature, found in environment *)

val close_all_views : unit -> unit

==> ocaml_3.09.2.orig.tar.gz: ocaml-3.09.2/otherlibs/labltk/browser/viewer.mli <==
(*************************************************************************)
(*                                                                       *)
(*                Objective Caml LablTk library                          *)
(*                                                                       *)
(*            Jacques Garrigue, Kyoto University RIMS                    *)
(*                                                                       *)
(*   Copyright 1999 Institut National de Recherche en Informatique et    *)
(*   en Automatique and Kyoto University.  All rights reserved.          *)
(*   This file is distributed under the terms of the GNU Library         *)
(*   General Public License, with the special exception on linking       *)
(*   described in file ../../../LICENSE.                                 *)
(*                                                                       *)
(*************************************************************************)

(* $Id: viewer.mli,v 1.7 2002/07/11 13:49:51 garrigue Exp $ *)

(* Module viewer *)
open Widget

val search_symbol : unit -> unit
        (* search a symbol in all modules in the path *)

val f : ?dir:string -> ?on:toplevel widget -> unit -> unit
        (* open then module viewer *)
val st_viewer : ?dir:string -> ?on:toplevel widget -> unit -> unit
        (* one-box viewer *)

val view_defined : env:Env.t -> ?show_all:bool -> Longident.t -> unit
        (* displays a signature, found in environment *)

val close_all_views : unit -> unit
